Module: SimpleCrud::ActionLambdas
- Included in:
- SimpleCrudController
- Defined in:
- lib/simple_crud/action_lambdas.rb
Overview
Builds the lambda installed as each action declared with simple_crud_for.
Builds the lambda installed as each action declared with simple_crud_for.